# Changelog

## [0.41.2](https://github.com/varfish-org/mehari/compare/v0.41.1...v0.41.2) (2026-03-22)


### Bug Fixes

* hide server functionality behind feature gate (enabled by default) ([#964](https://github.com/varfish-org/mehari/issues/964)) ([0031153](https://github.com/varfish-org/mehari/commit/00311532ac5d296277f85220d415d5a1cc96dbd3))

## [0.41.0](https://github.com/varfish-org/mehari/compare/v0.40.0...v0.41.0) (2026-03-21)


### Features

* Add python bindings via pyO3 ([#959](https://github.com/varfish-org/mehari/issues/959)) ([b2450be](https://github.com/varfish-org/mehari/commit/b2450be38bdf65aa0c21c5b77ea6770910bd46a5))
